CameraConfiguration class

Constructors

CameraConfiguration({required String outputPath, required CameraMode mode, TruvideoSdkCameraLensFacing lensFacing = TruvideoSdkCameraLensFacing.back, TruvideoSdkCameraFlashMode flashMode = TruvideoSdkCameraFlashMode.off, TruvideoSdkCameraOrientation? orientation, TruvideoSdkCameraImageFormat? imageFormat = TruvideoSdkCameraImageFormat.jpeg, bool? videoStabilizationEnabled = true, List<CameraResolution>? frontResolutions, CameraResolution? frontResolution, List<CameraResolution>? backResolutions, CameraResolution? backResolution, bool isStreamUpload = false})

Properties

backResolution CameraResolution?
final
backResolutions List<CameraResolution>?
final
flashMode TruvideoSdkCameraFlashMode
final
frontResolution CameraResolution?
final
frontResolutions List<CameraResolution>?
final
hashCode int
The hash code for this object.
no setterinherited
imageFormat TruvideoSdkCameraImageFormat?
final
isStreamUpload bool
final
lensFacing TruvideoSdkCameraLensFacing
final
mode CameraMode
final
orientation TruvideoSdkCameraOrientation?
final
outputPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoStabilizationEnabled bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited